/*!
 * Copyright (c) 2021, 2022 Eclipse Foundation, Inc.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0 which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 *
 * Contributors:
 *   Christopher Guindon <chris.guindon@eclipse-foundation.org>
 *   Eric Poirier <eric.poirier@eclipse-foundation.org>
 *   Zhou Fang <zhou.fang@eclipse-foundation.org>
 *
 * SPDX-License-Identifier: EPL-2.0
 */

import $ from 'jquery';
import 'jquery-match-height';
import displayErrMsg from '../utils/displayErrMsg';
import template from './templates/explore-working-groups/working-group-list.mustache';

const EclipseFdnWGsList = (async () => {
  const element = document.querySelector('.eclipsefdn-wgs-list');
  if (!element) {
    return;
  }

  let url = 'https://membership.eclipse.org/api/working_groups';
  let wgsData;
  try {
    wgsData = await (await fetch(url)).json();
    wgsData = wgsData.sort((a, b) => a.alias.localeCompare(b.alias));
  } catch (error) {
    displayErrMsg(element, error);
    return;
  }

  const populateWGNames = function () {
    // Use the short version of the name - without "Eclipse" and "Working Group"
    return this.title.replace('Eclipse ', '').replace(' Working Group', '');
  };

  const populateIds = function () {
    // Need to keep using those ids as they are used/referred on some other places
    const oldWGIds = {
      aice: 'aice-working-group',
      gemoc: 'gemoc-rc',
      'internet-things-iot': 'internet-of-things',
      sdv: 'software-defined-vehicle',
    };
    const oldId = oldWGIds[this.alias];
    return oldId ? oldId : this.alias;
  };

  const checkStatus = function () {
    switch (this.status) {
      case 'active':
        return 'Active';
      case 'proposed':
        return 'Proposed';
      case 'incubating':
        return 'Incubating';
      default:
        // Won't show wg that is inactive or in any invalid status
        return false;
    }
  };

  let filterOptionsArray = ['active', 'proposed', 'incubating'];
  // Keep those that exist in response data
  filterOptionsArray = filterOptionsArray.filter((option) => wgsData.find((wg) => wg.status.toLowerCase() === option));
  const filterOptions = {
    // Only show filter when there are 2 or more status in response data
    all: filterOptionsArray.length > 1,
    active: filterOptionsArray.includes('active'),
    proposed: filterOptionsArray.includes('proposed'),
    incubating: filterOptionsArray.includes('incubating'),
  };

  element.innerHTML = template({
    sections: wgsData,
    populateWGNames,
    populateIds,
    checkStatus,
    shouldShowFilterOptions: filterOptions,
  });

  const anchoredWG = window.location.hash.replace('#', '');
  anchoredWG && document.getElementById(anchoredWG).scrollIntoView({ behavior: 'smooth' });

  // Filter logic
  $(function () {
    $('.wg-links a').click(function () {
      let wg_item = $(this).attr('data-wg');
      if (wg_item === 'wg-all-item') {
        $('.wg-item')
          .fadeOut('300')
          .promise()
          .done(function () {
            $('.wg-item').fadeIn('300');
            $('.wg-item').matchHeight({ remove: true });
            $('.wg-item:visible').matchHeight();
          });
      } else {
        $('.wg-item')
          .fadeOut('300')
          .promise()
          .done(function () {
            $('.' + wg_item).fadeIn('300');
            $('.wg-item').matchHeight({ remove: true });
            $('.wg-item:visible').matchHeight();
          });
      }
    });

    $('.wg-all-item').click(function () {
      $('.wg-item').fadeIn('300');
      $('.wg-item').matchHeight({ remove: true });
      $('.wg-item:visible').matchHeight();
    });
  });

})();
export default EclipseFdnWGsList;
